==> sgq-business-0.1-sources.jar: com/herbocailleau/sgq/entities/SaleDAOAbstract.java <==
package com.herbocailleau.sgq.entities;

import com.herbocailleau.sgq.SGQDAOHelper.SGQEntityEnum;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.persistence.TopiaDAOImpl;
import org.nuiton.topia.persistence.TopiaEntity;

public abstract class SaleDAOAbstract<E extends Sale> extends TopiaDAOImpl<E> {

    @Override
    public Class<E> getEntityClass() {
        return (Class<E>)Sale.class;
    }

    @Override
    public SGQEntityEnum getTopiaEntityEnum() {
        return SGQEntityEnum.Sale;
    }

    public E findByDate(Date v) throws TopiaException {
        E result = findByProperty(Sale.DATE, v);
        return result;
    }

    public List<E> findAllByDate(Date v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.DATE, v);
        return result;
    }

    public E findByQuantity(double v) throws TopiaException {
        E result = findByProperty(Sale.QUANTITY, v);
        return result;
    }

    public List<E> findAllByQuantity(double v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.QUANTITY, v);
        return result;
    }

    public E findByPresentation(Presentation v) throws TopiaException {
        E result = findByProperty(Sale.PRESENTATION, v);
        return result;
    }

    public List<E> findAllByPresentation(Presentation v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.PRESENTATION, v);
        return result;
    }

    public E findByClient(Client v) throws TopiaException {
        E result = findByProperty(Sale.CLIENT, v);
        return result;
    }

    public List<E> findAllByClient(Client v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.CLIENT, v);
        return result;
    }

    @Override
    public <U extends TopiaEntity> List<U> findUsages(Class<U> type, E entity) throws TopiaException {
        return new ArrayList<U>();
    }

    @Override
    public Map<Class<? extends TopiaEntity>, List<? extends TopiaEntity>> findAllUsages(E entity) throws TopiaException {
        return new HashMap<Class<? extends TopiaEntity>, List<? extends TopiaEntity>>();
    }

} //SaleDAOAbstract<E extends Sale>

==> sgq-business-0.2-sources.jar: com/herbocailleau/sgq/entities/SaleDAOAbstract.java <==
package com.herbocailleau.sgq.entities;

import com.herbocailleau.sgq.SGQDAOHelper.SGQEntityEnum;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.persistence.TopiaDAOImpl;
import org.nuiton.topia.persistence.TopiaEntity;

public abstract class SaleDAOAbstract<E extends Sale> extends TopiaDAOImpl<E> {

    @Override
    public Class<E> getEntityClass() {
        return (Class<E>)Sale.class;
    }

    @Override
    public SGQEntityEnum getTopiaEntityEnum() {
        return SGQEntityEnum.Sale;
    }

    public E findByDate(Date v) throws TopiaException {
        E result = findByProperty(Sale.PROPERTY_DATE, v);
        return result;
    }

    public List<E> findAllByDate(Date v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.PROPERTY_DATE, v);
        return result;
    }

    public E findByQuantity(double v) throws TopiaException {
        E result = findByProperty(Sale.PROPERTY_QUANTITY, v);
        return result;
    }

    public List<E> findAllByQuantity(double v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.PROPERTY_QUANTITY, v);
        return result;
    }

    public E findByPresentation(Presentation v) throws TopiaException {
        E result = findByProperty(Sale.PROPERTY_PRESENTATION, v);
        return result;
    }

    public List<E> findAllByPresentation(Presentation v) throws TopiaException {
        List<E> result = findAllByProperty(Sale.PROPERTY_PRESENTATION, v);
        return result;
    }

    @Override
    public <U extends TopiaEntity> List<U> findUsages(Class<U> type, E entity) throws TopiaException {
        return new ArrayList<U>();
    }

    @Override
    public Map<Class<? extends TopiaEntity>, List<? extends TopiaEntity>> findAllUsages(E entity) throws TopiaException {
        return new HashMap<Class<? extends TopiaEntity>, List<? extends TopiaEntity>>();
    }

} //SaleDAOAbstract<E extends Sale>
